"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GasUtilitiesImpl = void 0;
/**
 * Google Apps Script の Utilities を使用するためのラッパークラス
 */
class GasUtilitiesImpl {
    /**
     * 署名を作成する
     *
     * @param text 署名対象テキスト
     * @param key 秘密鍵
     * @returns 署名
     */
    computeHmacSha256Signature(text, key) {
        return Utilities.computeHmacSha256Signature(text, key);
    }
    /**
     * Base64 Web Safe エンコードを行う
     *
     * @param data 対象データ
     * @returns エンコードされたデータ
     */
    base64EncodeWebSafe(data) {
        if (typeof data === 'string') {
            return Utilities.base64EncodeWebSafe(data).replace(/=+$/, '');
        }
        else {
            return Utilities.base64EncodeWebSafe(data).replace(/=+$/, '');
        }
    }
    /**
     * Base64 Web Safe デコードとオブジェクト化を行う
     *
     * @param data 対象データ
     * @returns オブジェクト
     */
    base64DecodeWebSafeAndToObject(data) {
        const decodedData = Utilities.base64DecodeWebSafe(data);
        const json = Utilities.newBlob(decodedData).getDataAsString();
        return JSON.parse(json);
    }
    /**
     * Sha512のハッシュ値を取得する
     *
     * @param data 対象データ
     * @returns Sha512のハッシュ値
     */
    sha512(data) {
        return Utilities.computeDigest(Utilities.DigestAlgorithm.SHA_512, data, Utilities.Charset.UTF_8);
    }
    /**
     * Base64 エンコードを行う
     *
     * @param data 対象データ
     * @returns エンコードされたデータ
     */
    base64Encode(data) {
        return Utilities.base64Encode(data);
    }
}
exports.GasUtilitiesImpl = GasUtilitiesImpl;
